@@ -313,6 +313,16 @@ impl Optimizer<'_> {
 
         match callee {
             Expr::Arrow(f) => {
+                if f.is_async {
+                    log::trace!("iife: [x] Cannot inline async fn");
+                    return;
+                }
+
+                if f.is_generator {
+                    log::trace!("iife: [x] Cannot inline generator");
+                    return;
+                }
+
                 if self.ctx.in_top_level() && !self.ctx.in_call_arg && self.options.negate_iife {
                     match &f.body {
                         BlockStmtOrExpr::BlockStmt(body) => {
@@ -431,6 +441,11 @@ impl Optimizer<'_> {
                     }
                 }
 
+                if f.function.is_async {
+                    log::trace!("iife: [x] Cannot inline async fn");
+                    return;
+                }
+
                 if f.function.is_generator {
                     log::trace!("iife: [x] Cannot inline generator");
                     return;
